@@ -15,7 +15,7 @@
 #'          \item{For \code{remove_labels()}}{Either a numeric vector, indicating
 #'          the position of one or more label attributes that should be removed;
 #'          a character vector with names of label attributes that should be
-#'          removed; or a \code{\link[haven]{tagged_na}} to remove the labels
+#'          removed; or a \code{\link[haven:tagged_na]{tagged_na()}} to remove the labels
 #'          from specific NA values.}
 #'          }
 #'
@@ -46,14 +46,15 @@
 #' x <- add_labels(efc$e42dep, labels = c(`nothing` = 5))
 #' get_labels(x)
 #'
-#' library(dplyr)
-#' x <- efc %>%
-#'   # select three variables
-#'   dplyr::select(e42dep, c172code, c161sex) %>%
-#'   # only add new label to two of those
-#'   add_labels(e42dep, c172code, labels = c(`nothing` = 5))
-#' # see data frame, with selected variables having new labels
-#' get_labels(x)
+#' if (require("dplyr")) {
+#'   x <- efc %>%
+#'     # select three variables
+#'     dplyr::select(e42dep, c172code, c161sex) %>%
+#'     # only add new label to two of those
+#'     add_labels(e42dep, c172code, labels = c(`nothing` = 5))
+#'   # see data frame, with selected variables having new labels
+#'   get_labels(x)
+#' }
 #'
 #' x <- add_labels(efc$e42dep, labels = c(`nothing` = 5, `zero value` = 0))
 #' get_labels(x, values = "p")
@@ -66,15 +67,16 @@
 #' get_labels(x, values = "p")
 #'
 #' # replace specific missing value (tagged NA)
-#' library(haven)
-#' x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
-#'               c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-#'                 "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
-#' # get current NA values
-#' x
-#' # tagged NA(c) has currently the value label "First", will be
-#' # replaced by "Second" now.
-#' replace_labels(x, labels = c("Second" = tagged_na("c")))
+#' if (require("haven")) {
+#'   x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
+#'                 c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+#'                   "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
+#'   # get current NA values
+#'   x
+#'   # tagged NA(c) has currently the value label "First", will be
+#'   # replaced by "Second" now.
+#'   replace_labels(x, labels = c("Second" = tagged_na("c")))
+#' }
 #'
 #'
 #' # remove_labels()
@@ -85,19 +87,20 @@
 #' x <- remove_labels(efc$e42dep, labels = "independent")
 #' get_labels(x, values = "p")
 #'
-#' library(haven)
-#' x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
-#'               c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-#'                 "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
-#' # get current NA values
-#' get_na(x)
-#' get_na(remove_labels(x, labels = tagged_na("c")))
+#' if (require("haven")) {
+#'   x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
+#'                 c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+#'                   "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
+#'   # get current NA values
+#'   get_na(x)
+#'   get_na(remove_labels(x, labels = tagged_na("c")))
+#' }
 #' @export
 add_labels <- function(x, ..., labels) {
 
   # check for valid value. value must be a named vector
-  if (is.null(labels)) stop("`labels` is NULL.", call. = F)
-  if (is.null(names(labels))) stop("`labels` must be a named vector.", call. = F)
+  if (is.null(labels)) stop("`labels` is NULL.", call. = FALSE)
+  if (is.null(names(labels))) stop("`labels` must be a named vector.", call. = FALSE)
 
   # evaluate arguments, generate data
   dots <- as.character(match.call(expand.dots = FALSE)$`...`)
@@ -119,9 +122,9 @@ add_labels_helper <- function(x, value) {
   # get current labels of `x`
   current.labels <- get_labels(
     x,
-    attr.only = T,
+    attr.only = TRUE,
     values = "n",
-    non.labelled = F,
+    non.labelled = FALSE,
     drop.na = TRUE
   )
 
