@@ -3,7 +3,7 @@
 #'
 #' @description Duplicated value labels in variables may cause troubles when
 #'              saving labelled data, or computing cross tabs (cf.
-#'              \code{\link[sjmisc:flat_table]{flat_table()}} or \code{\link[sjPlot:plot_xtab]{plot_xtab()}}).
+#'              \code{sjmisc::flat_table()} or \code{sjPlot::plot_xtab()}).
 #'              \code{tidy_labels()} repairs duplicated value labels by suffixing
 #'              them with the associated value.
 #'
@@ -19,23 +19,23 @@
 #' @return \code{x}, with "repaired" (unique) value labels for each variable.
 #'
 #' @examples
-#' library(sjmisc)
-#' set.seed(123)
-#' x <- set_labels(
-#'   sample(1:5, size = 20, replace = TRUE),
-#'   labels = c("low" = 1, ".." = 2, ".." = 3, ".." = 4, "high" = 5)
-#' )
-#' frq(x)
+#' if (require("sjmisc")) {
+#'   set.seed(123)
+#'   x <- set_labels(
+#'     sample(1:5, size = 20, replace = TRUE),
+#'     labels = c("low" = 1, ".." = 2, ".." = 3, ".." = 4, "high" = 5)
+#'   )
+#'   frq(x)
 #'
-#' z <- tidy_labels(x)
-#' frq(z)
+#'   z <- tidy_labels(x)
+#'   frq(z)
 #'
-#' z <- tidy_labels(x, sep = ".")
-#' frq(z)
-#'
-#' z <- tidy_labels(x, remove = TRUE)
-#' frq(z)
+#'   z <- tidy_labels(x, sep = ".")
+#'   frq(z)
 #'
+#'   z <- tidy_labels(x, remove = TRUE)
+#'   frq(z)
+#' }
 #' @export
 tidy_labels <- function(x, ..., sep = "_", remove = FALSE) {
   dots <- as.character(match.call(expand.dots = FALSE)$`...`)
@@ -56,14 +56,13 @@ tidy_labels <- function(x, ..., sep = "_", remove = FALSE) {
 
 tidy_labels_helper <- function(x, sep, remove) {
   # get value labels from variable. drop unused labels
-  labs <-
-    get_labels(
-      x,
-      attr.only = TRUE,
-      values = FALSE,
-      drop.unused = TRUE,
-      drop.na = TRUE
-    )
+  labs <- get_labels(
+    x,
+    attr.only = TRUE,
+    values = FALSE,
+    drop.unused = TRUE,
+    drop.na = TRUE
+  )
 
   # no labels? then return...
   if (is.null(labs)) return(x)
